@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -90,6 +86,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
         final String metaValue_mn = "\u8499\u53e4\u6587";
         final String metaValue_mr = "\u99ac\u62c9\u5730\u6587";
         final String metaValue_my = "\u7dec\u7538\u6587";
+        final String metaValue_or = "\u6b50\u8fea\u4e9e\u6587";
         final String metaValue_sa = "\u68b5\u6587";
         final String metaValue_sd = "\u4fe1\u5fb7\u6587";
         final String metaValue_su = "\u5dfd\u4ed6\u6587";
@@ -891,7 +888,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "ch", "\u67e5\u83ab\u6d1b\u6587" },
             { "%%REVISED", "\u5df2\u4fee\u8a02\u7684\u62fc\u5b57\u5b78" },
             { "co", "\u79d1\u897f\u5609\u6587" },
-            { "Orya", "\u6b50\u5229\u4e9e\u6587" },
+            { "Orya", metaValue_or },
             { "cr", "\u514b\u91cc\u6587" },
             { "cs", "\u6377\u514b\u6587" },
             { "cu", "\u5b97\u6559\u65af\u62c9\u592b\u6587" },
@@ -1120,7 +1117,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "kaw", "\u5361\u5a01\u6587" },
             { "dtp", "\u4e2d\u90e8\u675c\u9806\u6587" },
             { "Modi", metaValue_mr },
-            { "or", "\u6b50\u8fea\u4e9e\u6587" },
+            { "or", metaValue_or },
             { "os", "\u5967\u585e\u63d0\u6587" },
             { "%%ALALC97", "\u7f8e\u570b\u570b\u6703\u5716\u66f8\u9928\u6a19\u6e96\u65b9\u6848\u7f85\u99ac\u5316\uff081997\u5e74\u7248\uff09" },
             { "bpy", "\u6bd4\u4ec0\u5974\u666e\u840a\u5229\u4e9e\u6587" },
@@ -1175,7 +1172,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "key.cu", "\u8ca8\u5e63" },
             { "ro", "\u7f85\u99ac\u5c3c\u4e9e\u6587" },
             { "%%SAAHO", metaValue_ssy },
-            { "type.nu.orya", "\u6b50\u5229\u4e9e\u6578\u5b57" },
+            { "type.nu.orya", "\u6b50\u8fea\u4e9e\u6578\u5b57" },
             { "type.nu.hanidec", "\u4e2d\u6587\u5341\u9032\u4f4d\u6578\u5b57" },
             { "ru", "\u4fc4\u6587" },
             { "bss", "\u963f\u5eab\u8272\u6587" },
@@ -1270,7 +1267,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "Sylo", "\u5e0c\u6d1b\u5f1f\u7d0d\u683c\u91cc\u6587" },
             { "ve", "\u6eab\u9054\u6587" },
             { "Wara", "\u74e6\u90ce\u5947\u8482\u6587\u5b57" },
-            { "type.ca.roc", "\u6c11\u570b\u66c6" },
+            { "type.ca.roc", "\u570b\u66c6" },
             { "vi", "\u8d8a\u5357\u6587" },
             { "kho", "\u548c\u95d0\u6587" },
             { "khq", "\u897f\u6851\u6d77\u6587" },
